summaryrefslogtreecommitdiff
path: root/src/fstab-generator
diff options
context:
space:
mode:
authorYu Watanabe <watanabe.yu+github@gmail.com>2021-03-06 10:12:55 +0900
committerZbigniew Jędrzejewski-Szmek <zbyszek@in.waw.pl>2021-03-06 08:52:43 +0100
commit5a12d1ca1a29b03fe13b6758fdc329f4e7f695f9 (patch)
treee41d6cb47527eaed4f8554b6db21da02c5ee660a /src/fstab-generator
parent996c83903da5bf8b371314b4207ff97afeef65a4 (diff)
downloadsystemd-5a12d1ca1a29b03fe13b6758fdc329f4e7f695f9.tar.gz
fstab-generator: fix typo
Diffstat (limited to 'src/fstab-generator')
-rw-r--r--src/fstab-generator/fstab-generator.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/fstab-generator/fstab-generator.c b/src/fstab-generator/fstab-generator.c
index 6df7fa5328..0910a9aa61 100644
--- a/src/fstab-generator/fstab-generator.c
+++ b/src/fstab-generator/fstab-generator.c
@@ -423,7 +423,7 @@ static int add_mount(
* mount.nfs (so systemd can manage the job-control aspects of 'bg'),
* we need to explicitly preserve that default, and also ensure
* the systemd mount-timeout doesn't interfere.
* By placing these options first, they can be over-ridden by
* settings in /etc/fstab. */
opts = strjoina("x-systemd.mount-timeout=infinity,retry=10000,nofail,", opts, ",fg");
SET_FLAG(flags, NOFAIL, true);
@@ -699,9 +699,9 @@ static int add_sysroot_mount(void) {
if (!what)
return log_oom();
- fstype = arg_root_fstype ?: "tmpfs"; /* tmpfs, unless overriden */
+ fstype = arg_root_fstype ?: "tmpfs"; /* tmpfs, unless overridden */
- default_rw = true; /* writable, unless overriden */;
+ default_rw = true; /* writable, unless overridden */;
} else {
what = fstab_node_to_udev_node(arg_root_what);
@@ -710,7 +710,7 @@ static int add_sysroot_mount(void) {
fstype = arg_root_fstype; /* if not specified explicitly, don't default to anything here */
- default_rw = false; /* read-only, unless overriden */
+ default_rw = false; /* read-only, unless overridden */
}
if (!arg_root_options)
@@ -423,7 +423,7 @@ static int add_mount(
* we need to explicitly preserve that default, and also ensure
* the systemd mount-timeout doesn't interfere.
- * By placing these options first, they can be over-ridden by
+ * By placing these options first, they can be overridden by
* settings in /etc/fstab. */
opts = strjoina("x-systemd.mount-timeout=infinity,retry=10000,nofail,", opts, ",fg");